Kahgean
=======

Kahgean is a set of handy utils for daily development.

``kahgean.options`` makes it easy to parse command-line
arguments and configuration file by just one set of defines.

``kahgean.logkit`` makes configuring log handlers become easy.

``kahgean.daemonize`` can help developers to write daemon programs.

``kahgean.initial`` provides some functions that should be invoked
as soon as possible before doing any meaningful processing.

``kahgean.ipv4addr`` provides handy classes for describing IPv4
addresses and/or subnetworks.
